Rev 4871: Fix edge references in lp_api and more comments. in file:///home/vila/src/bzr/bugs/583667-lp-no-edge-2.1/

Vincent Ladeuil v.ladeuil+lp at free.fr
Fri Nov 26 18:10:01 GMT 2010


At file:///home/vila/src/bzr/bugs/583667-lp-no-edge-2.1/

------------------------------------------------------------
revno: 4871
revision-id: v.ladeuil+lp at free.fr-20101126181001-usykban3mhatv9a2
parent: v.ladeuil+lp at free.fr-20101126163145-pa05nogp9of79mxa
committer: Vincent Ladeuil <v.ladeuil+lp at free.fr>
branch nick: 583667-lp-no-edge-2.1
timestamp: Fri 2010-11-26 19:10:01 +0100
message:
  Fix edge references in lp_api and more comments.
-------------- next part --------------
=== modified file 'bzrlib/bzrdir.py'
--- a/bzrlib/bzrdir.py	2010-04-15 08:50:40 +0000
+++ b/bzrlib/bzrdir.py	2010-11-26 18:10:01 +0000
@@ -3109,7 +3109,7 @@
         # XXX: It's a bit ugly that the network name is here, because we'd
         # like to believe that format objects are stateless or at least
         # immutable,  However, we do at least avoid mutating the name after
-        # it's returned.  See <https://bugs.edge.launchpad.net/bzr/+bug/504102>
+        # it's returned.  See <https://bugs.launchpad.net/bzr/+bug/504102>
         self._network_name = None
 
     def __repr__(self):

=== modified file 'bzrlib/lockdir.py'
--- a/bzrlib/lockdir.py	2010-11-26 16:19:57 +0000
+++ b/bzrlib/lockdir.py	2010-11-26 18:10:01 +0000
@@ -582,7 +582,7 @@
                     deadline_str = time.strftime('%H:%M:%S',
                                                  time.localtime(deadline))
                 lock_url = self.transport.abspath(self.path)
-                # See <https://bugs.edge.launchpad.net/bzr/+bug/250451>
+                # See <https://bugs.launchpad.net/bzr/+bug/250451>
                 # the URL here is sometimes not one that is useful to the
                 # user, perhaps being wrapped in a lp-%d or chroot decorator,
                 # especially if this error is issued from the server.

=== modified file 'bzrlib/plugins/launchpad/lp_api.py'
--- a/bzrlib/ui/text.py	2010-05-26 02:19:33 +0000
+++ b/bzrlib/ui/text.py	2010-11-26 18:10:01 +0000
@@ -153,7 +153,7 @@
         """Construct and return a new ProgressView subclass for this UI.
         """
         # with --quiet, never any progress view
-        # <https://bugs.edge.launchpad.net/bzr/+bug/320035>.  Otherwise if the
+        # <https://bugs.launchpad.net/bzr/+bug/320035>.  Otherwise if the
         # user specifically requests either text or no progress bars, always
         # do that.  otherwise, guess based on $TERM and tty presence.
         if self.is_quiet():



More information about the bazaar-commits mailing list
--- a/bzrlib/plugins/launchpad/lp_api.py	2010-03-03 22:59:21 +0000
+++ b/bzrlib/plugins/launchpad/lp_api.py	2010-11-26 18:10:01 +0000
@@ -39,7 +39,6 @@
     raise errors.DependencyNotPresent('launchpadlib', e)
 
 from launchpadlib.launchpad import (
-    EDGE_SERVICE_ROOT,
     STAGING_SERVICE_ROOT,
     Launchpad,
     )
@@ -72,7 +71,6 @@
 
 LAUNCHPAD_API_URLS = {
     'production': 'https://api.launchpad.net/beta/',
-    'edge': EDGE_SERVICE_ROOT,
     'staging': STAGING_SERVICE_ROOT,
     'dev': 'https://api.launchpad.dev/beta/',
     }
@@ -81,8 +79,8 @@
 def _get_api_url(service):
     """Return the root URL of the Launchpad API.
 
-    e.g. For the 'edge' Launchpad service, this function returns
-    launchpadlib.launchpad.EDGE_SERVICE_ROOT.
+    e.g. For the 'staging' Launchpad service, this function returns
+    launchpadlib.launchpad.STAGING_SERVICE_ROOT.
 
     :param service: A `LaunchpadService` object.
     :return: A URL as a string.

=== modified file 'bzrlib/ui/text.py'